local defaultBar = {}

local reg = LibStub("AceConfigRegistry-3.0")
local event = LibStub("AceEvent-3.0")
local Strata = { "BACKGROUND", "LOW", "MEDIUM", "HIGH", "DIALOG", "FULLSCREEN", "FULLSCREEN_DIALOG", "TOOLTIP" }
local angles = {[180] = { 1,0,1,1,0,0,0,1}, [0] = {0,1,0,0,1,1,1,0}, [270] = {1,1,0,1,1,0,0,0}, [90] = {0,0,1,0,0,1,1,1}}


--[[ Base Bar functions ]] --
local function cloneTable(t)
	local clone = {}
	for i,v in pairs(t) do
		if type(v) == "table" then
			clone[i] = cloneTable(v)
		else
			clone[i] = v
		end
	end
	return clone
end



local Connections = {	["bottom"] = {"TOPLEFT", "BOTTOMLEFT"},
						["top"] = { "BOTTOMLEFT", "TOPLEFT"},
						["left"] = { "TOPRIGHT", "TOPLEFT"},
						["right"] = { "TOPLEFT", "TOPRIGHT"},
						[0] = { "LEFT", "RIGHT" },
						[90] = { "TOP", "BOTTOM" },
						[180] = { "RIGHT", "LEFT"},
						[270] = { "BOTTOM", "TOP"}
					}


Xparky.BaseBar = {
	Attached = "left",
	Xoffset = 0,
	Yoffset = 0,
	Thickness = 8,
	Attach = "UIParent"
}

local BaseBar = Xparky.BaseBar

function BaseBar:Width(Size)
	if self.Rotate == 0 or self.Rotate == 180 then
		if not Size then
			return self.Anchor:GetWidth()
		end
		self.Anchor:SetWidth(Size)
	else
		if not Size then 
			return self.Anchor:GetHeight()
		end
		self.Anchor:SetHeight(Size)
	end
end

function BaseBar:Height(Size)
	if self.Rotate == 0 or self.Rotate == 180 then
		if not Size then
			return self.Anchor:GetHeight()
		end
		self.Anchor:SetHeight(Size)
	else
		if not Size then
			return self.Anchor:GetWidth()
		end
		self.Anchor:SetWidth(Size)
	end
end

function BaseBar:ConstructBar()
	local Attached = nil

	local FrameAnchorFrom, FrameAnchorTo
	local BarAnchorFrom, BarAnchorTo, x, y
	
	FrameAnchorFrom = Connections[self.Attached][1]
	FrameAnchorTo = Connections[self.Attached][2]
	BarAnchorFrom = Connections[self.Rotate][1]
	BarAnchorTo = Connections[self.Rotate][2]

	-- Adjust the width of all the sections according to bar type and values
	
	self.Anchor = CreateFrame("Frame", self.Name.."XparkyAnchor", UIParent)
	self.Anchor:EnableMouse(true)
	self.Anchor:RegisterForDrag("LeftButton")
	self.Anchor:SetMovable(true)
	self.Anchor:SetScript("OnDragStart", function(self)
				self:StartMoving()
		end)
	self.Anchor:SetScript("OnDragStop", function(self)
			self:StopMovingOrSizing()
		end)

	-- Reattach to parent anchor correctly
	self.Anchor:ClearAllPoints()
	Attached = self.Attach and getglobal(self.Attach) or nil
	Xparky:Print("Attached is "..self.Attach)
	self.Anchor:SetParent(Attached or UIParent)
	if Attached then
		Xparky:Print("Putting bar in predefined location")
		self.Anchor:SetPoint("CENTER", UIParent)
--		self.Anchor:SetPoint(FrameAnchorFrom, Attached, FrameAnchorTo, tonumber(self.Xoffset) or 0, tonumber(self.Yoffset) or 0)
	end
	
	Attached = self.Anchor
	Xparky:Print("This bar has ".. #self.Sections.." sections")
	-- Attach each section according to orientation
	for i, Bar in ipairs(self.Sections) do
		Xparky:Print("Attaching Bar - ".. i)
		if Attached == self.Anchor then -- If we're attaching the first section
			Bar:ConstructBar(BarAnchorFrom, BarAnchorTo, Attached, true) -- attach to the base background bar
		else
			Bar:ConstructBar(BarAnchorFrom, BarAnchorTo, Attached) -- attach to the end of the previous section
		end
		Attached = Bar.Base
	end

end



